unit svcExample2;


interface

uses
    Windows,
    Messages,
    SysUtils,
    Classes,
    Graphics,
    Dialogs,
    Controls,
    SvCom_WinSvc,
    SvCom_NTService;

type
  TSampleService2 = class(TNTService)
    procedure SampleService2Start(Sender: TNtService;
      var DoAction: Boolean);
    procedure SampleService2Stop(Sender: TNtService;
      var DoAction: Boolean);
    procedure SampleService2Continue(Sender: TNtService;
      var DoAction: Boolean);
    procedure SampleService2Pause(Sender: TNtService;
      var DoAction: Boolean);
    procedure SampleService2Execute(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  SampleService2: TSampleService2;

implementation

{$R *.DFM}


procedure TSampleService2.SampleService2Start(Sender: TNtService;
  var DoAction: Boolean);
var i: Integer;
    S: String;
begin
    for i:=0 to ParamCount-1 do
    begin
        S := (Format('Params[%d]',[i]));
        SvSendValue(dekInfo,PChar(S),Param[i]);
    end;
    // This service performs a very importan work at startup - it sleeps
    // (what is more important then sleep ?)
    // This work requires a lot of time so we should
    // notify the system that we are alive.
    for i:=1 to 10 do
    begin
        Sleep(1000);
        ReportStatus; // It notifies the system that we are alive
                      // The interval between calls of ReportStatus
                      // should not exceed the WaitHint value.
                      // If the service start is fast enough then this call
                      // is not necessary
    end;
end;

procedure TSampleService2.SampleService2Stop(Sender: TNtService;
  var DoAction: Boolean);
var i: Integer;
begin
    SvSendCheckpoint('Stopping',StatusHandle);

//  The code below is removed because interactive services are prohibited by Microsoft.
//  Starting from Vista service application can not show anything to 
(*
    // Four lines of code below demonstrates how to show the simple
    // message box from a service. Note that our service is not
    // interactive but it is able to show messages.
    DoAction:=
    MessageBoxEx(0,'The SvCom example service will be stopped.'#13#10+
    'Are you sure ?','Service confirmation',
    MB_YESNO or MB_ICONQUESTION or MB_SERVICE_NOTIFICATION,0) = IDYES;
*)

    // The service behavior at stop is under the same
    // rules as its starting behavior.
    // For example we can do the same actions as OnStart.
    if DoAction then
    for i:=1 to 10 do
    begin
        Sleep(1000);
        ReportStatus;
    end;
    SvSendClearToCheckpoint;
end;

procedure TSampleService2.SampleService2Continue(Sender: TNtService;
  var DoAction: Boolean);
var i: Integer;
begin
    SvSendMethodEnter('Continue',StatusHandle);
    // And OnContinue too...
    for i:=1 to 10 do
    begin
        Sleep(1000);
        ReportStatus;
    end;
    SvSendMethodLeave('Continue');
end;

procedure TSampleService2.SampleService2Pause(Sender: TNtService;
  var DoAction: Boolean);
var i: Integer;
begin
    // As well as OnPause...
    for i:=1 to 10 do
    begin
        Sleep(1000);
        ReportStatus;
        SvSendValue(dekInfo,'i',i);
    end;
end;

procedure TSampleService2.SampleService2Execute(Sender: TObject);
begin
    // The OnExecute method can perform some work too.
    // But in this case we need not to report service status,
    // we only need to process the service control requests.
    // To do it we call the ProcessRequests method with False parameter.
    // It means that we do not wait the messages. Note that the True parameter
    // means that the ProcessRequests call should not return until service stopped -
    // and may be sure - it will not return.
    while True do
    begin
        ProcessRequests(False);
        if Terminated then break;
        Sleep(1000);
        SvSendMessage(dekWarning,'Service is running',StatusHandle);
    end;
end;

end.

